@@ -19,6 +19,8 @@ import gi
 gi.require_version("NM", "1.0")
 from gi.repository import NM, GLib, Gio
 
+import network_test_base
+
 nmclient = NM.Client.new()
 
 class TestNetplan(unittest.TestCase):
@@ -79,6 +81,7 @@ class TestNetplan(unittest.TestCase):
         argv += os.environ.get("NM_TEST_DAEMON_ARGS", "").strip().split()
 
         p = subprocess.Popen(argv, stdout=f_log, stderr=subprocess.STDOUT)
+        network_test_base.wait_nm_online()
         # automatically terminate process at end of test case
         self.addCleanup(p.wait)
         self.addCleanup(p.terminate)
